/* eslint-disable @typescript-eslint/no-var-requires */
import React from 'react'
import IcoMoon from 'react-icomoon'
import { Animated, Easing, Platform, StyleProp, StyleSheet, TextStyle, ViewStyle } from 'react-native'

import { colors } from '@holi/ui/styles/globalVars'

export type HoliIconProps = {
  icon: string
  spinning?: boolean
  color?: string
  filled?: boolean
  size?: number
  testID?: string
  style?: StyleProp<ViewStyle | TextStyle>
}

const HoliIcon: React.VoidFunctionComponent<HoliIconProps> = (props: HoliIconProps) => {
  const iconSet = props?.filled
    ? require('@holi/ui/assets/fonts/HoliIcons/filled/selection.json')
    : require('@holi/ui/assets/fonts/HoliIcons/regular/selection.json')

  const mobileProps =
    Platform.OS === 'web'
      ? {}
      : {
          native: true,
          SvgComponent: require('react-native-svg').Svg,
          PathComponent: require('react-native-svg').Path,
        }

  const icoMoonProps = { size: 24, ...props }
  delete icoMoonProps.filled
  delete icoMoonProps.spinning
  const styling = {
    color: props?.color || colors.foreground30,
    borderStyle: 'solid',
    borderWidth: 0,
    ...StyleSheet.flatten<ViewStyle>(props?.style),
  }

  if (props.spinning) {
    const spinValue = new Animated.Value(0)
    const spin = spinValue.interpolate({
      inputRange: [0, 1],
      outputRange: ['0deg', '360deg'],
    })
    Animated.loop(
      Animated.timing(spinValue, {
        toValue: 1,
        duration: 1000,
        easing: Easing.linear,
        useNativeDriver: false,
      })
    ).start(() => {
      spinValue.setValue(0)
    })
    return (
      <Animated.View style={{ ...(props.spinning && { transform: [{ rotate: spin }] }) }}>
        <IcoMoon iconSet={iconSet} {...mobileProps} {...icoMoonProps} style={styling} />
      </Animated.View>
    )
  }

  return <IcoMoon iconSet={iconSet} {...mobileProps} {...icoMoonProps} style={styling} />
}

export default HoliIcon
